pub struct ParseError {
pub message: String,
pub range: TextRange,
pub severity: ParseSeverity,
}Expand description
A parse error with a message and the source range it points at.
Fields
message: Stringrange: TextRangeByte range in the source that the error points at.
severity: ParseSeverityWhether this diagnostic blocks compilation. Defaults to Error for
every existing diagnostic (Parser::error); only Parser::warning
produces Warning.